function RealPlot = Cpx2Surf(IMAG, IMAGVib)
% INPUT PARAMETERS:
% IMAG = Complex amplitude of the recovered map
% IMAGVib = Real amplitude of the groundtruth
% OUTPUT PARAMETER
% RealPlot = Real amplitude of the recovered map

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Amplitudes normalization
IMAG = IMAG ./ max(IMAG(:));
[NbRows,NbColumns] = size(IMAG);

% Phase shifting

VectorIMAG = [real(IMAG(:)),imag(IMAG(:))];
AutoCov = VectorIMAG'*VectorIMAG;
[EigenVectors,~] = eigs(AutoCov);
PhasedIMAG = real(VectorIMAG*EigenVectors(:,1));
PhasedIMAG = PhasedIMAG ./ norm(PhasedIMAG);

% solve global sign ambiguity
if nargin==2
    [~, indmax] = max(abs(PhasedIMAG(:).*IMAGVib(:))); 
    PhasedIMAG = PhasedIMAG * sign(PhasedIMAG(indmax)*IMAGVib(indmax));
end

RealPlot = reshape(PhasedIMAG,NbRows,NbColumns);

