function [phi, phi_norm, phi0] = build_measurement_matrix(k, positions, ALGOP,sb, masque)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

N = size(positions, 1);
Nxy = ALGOP.DicoSizeX*ALGOP.DicoSizeY;

phi = zeros(N,Nxy);
phi_norm = zeros(N,Nxy);
phi0 = zeros(N,Nxy);


for u =1:N
phi_s = (mesure_plane(k, positions(u,1), positions(u,2), positions(u,3), ALGOP)) .* masque;
    phi_s_t = sb(conj(phi_s));
    phi(u,:) = conj(phi_s_t(:));
    phi0(u,:) = phi_s(:);   
end

for u = 1:Nxy
    phi_norm(:,u) = phi(:,u)/norm(phi(:,u));
end

end



function phi = mesure_plane (k, xm, ym, zm, ALGOP)

% construction du vecteur correspondant  une mesure faite en un point de
% coordonnes (xm ym zm)

% utilise l'expression de gv page 36 2.74 de Fourier Acoustics

rho0 = 1.2;
c = 340;

Dx = ALGOP.DicoSizeX;
Dy = ALGOP.DicoSizeY;
stepx = ALGOP.StepX;
stepy = ALGOP.StepY;

x = ((-Dx+1)/2 : (Dx-1)/2) * stepx;
y = ((-Dy+1)/2 : (Dy-1)/2) * stepy;

r2 = repmat((x-xm)'.^2,1,Dy) + repmat((y-ym).^2,Dx,1) + zm^2;

r = sqrt(double(r2));

phi = -rho0*c*k*1i*exp(-1i*k*r)./(r*2*pi) * stepx * stepy;

end