function [SelectedGroundTruthODS RelevantGroundTruthODS] = extract_groundtruth_ODS(SpectraVibro,SPECPVibro,VibroANTP)
%% Usage
% GroundTruthODS = extract_groundtruth_ODS(SpectraVibro,SPECPVibro,VIBROP)
%
% Extract relevant ODS from vibrometry spectra
%
% Input:
%
% Output
%   GroundTruthODS: Nx x Ny x NbFreqsODS spatial Operating Deflection Shapes
%                                      for frequencies selected in
%                                      SPECPVibro.SelectedFreqIndices

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Reshape the spectra for each (temporal) frequency 

NbX = length(unique(VibroANTP.XYPos(:,1)));
NbY = length(unique(VibroANTP.XYPos(:,2)));

ReshapedSpectra = zeros(NbX,NbY,SPECPVibro.NbFreqs);
for ii = 1:SPECPVibro.NbFreqs
     ReshapedSpectra(:,:,ii) = reshape(SpectraVibro(:,ii),NbY,NbX).'; 
end

%% Detect spatial location of unsuccessful measurements
[row, col] = find(ReshapedSpectra(:,:,1) == 0);
support = ones(NbX,NbY);

NbUnsuccessful = 0;
for ii = 1 : size(col)
    support(row(ii),col(ii)) = 0;
    NbUnsuccessful = NbUnsuccessful+1;
end
support = logical(support);

%% Create output
RelevantGroundTruthODS = ReshapedSpectra(:,:,SPECPVibro.RelevantFreqIndices);
SelectedGroundTruthODS = ReshapedSpectra(:,:,SPECPVibro.SelectedFreqIndices);

% Unsuccessful measurements interpolation
disp(['Interpolating unsuccesful measurements (' num2str(NbUnsuccessful) '/' num2str(SPECPVibro.NbChannels) ')']);

for k = 1 : length(SPECPVibro.SelectedFreqIndices)
    SelectedGroundTruthODS(:,:,k) = inpaint_ODS(SelectedGroundTruthODS(:,:,k), support);
    SelectedGroundTruthODS(:,:,k) = median_filter_2d(SelectedGroundTruthODS(:,:,k));
end

for k = 1 : length(SPECPVibro.RelevantFreqIndices)
    RelevantGroundTruthODS(:,:,k) = inpaint_ODS(RelevantGroundTruthODS(:,:,k), support);
    RelevantGroundTruthODS(:,:,k) = median_filter_2d(RelevantGroundTruthODS(:,:,k));
end

