function v = irfft2(rf, m, n)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin==1
    [m n] = size(rf);
end

fm = zeros(size(rf));

if mod(m,2) == 0
    fm(1,:) = rf(1,:)*sqrt(m);
    fm(2:(m/2),:) = (rf(2:(m/2),:) - i*rf((m/2+1):(end-1),:))*sqrt(m/2);
    fm(end:-1:(m/2+2),:) = (rf(2:(m/2),:) + i*rf((m/2+1):(end-1),:))*sqrt(m/2);
    fm(m/2+1,:) = rf(end,:)*sqrt(m);
else
    fm(1,:) = rf(1,:)*sqrt(m);
    fm(2:((m-1)/2),:) = (rf(2:((m-1)/2),:) - i*rf(((m+1)/2):end,:))*sqrt(m/2);
    fm(((m+1)/2):end,:) = (rf((m/2):-1:2,:) + i*rf(end:-1:((m+1)/2),:))*sqrt(m/2);
end

fm = fm.';
f = zeros(size(fm));

if mod(n,2) == 0
    f(1,:) = fm(1,:)*sqrt(n);
    f(2:(n/2),:) = (fm(2:(n/2),:) - i*fm((n/2+1):(end-1),:))*sqrt(n/2);
    f(end:-1:(n/2+2),:) = (fm(2:(n/2),:) + i*fm((n/2+1):(end-1),:))*sqrt(n/2);
    f(n/2+1,:) = fm(end,:);
else
    f(1,:) = fm(1,:)*sqrt(n);
    f(2:((n-1)/2),:) = (fm(2:((n-1)/2),:) - i*fm(((n+1)/2):end,:))*sqrt(n/2);
    f(((n+1)/2):end,:) = (fm((n/2):-1:2,:) + i*fm(end:-1:((n+1)/2),:))*sqrt(n/2);
end

f = f.';

v = ifft2(f, m, n);

end