function rf = rfft2(v, m, n)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin==1
    [m n] = size(v);
end

f = fft2(v, m, n);

rfm = zeros(size(f));

if mod(m,2) == 0
    rfm(1,:) = f(1,:)/sqrt(m);
    rfm(2:(m/2),:) = (f(2:(m/2),:) + f(end:-1:(m/2+2),:)) / sqrt(2*m);
    rfm((m/2+1):(end-1),:) = 1i*(f(2:(m/2),:) - f(end:-1:(m/2+2),:)) / sqrt(2*m);
    rfm(end,:) = f(m/2+1,:)/sqrt(m);
else
    rfm(1,:) = f(1,:);
    rfm(2:((m-1)/2),:) = (f(2:((m-1)/2),:) + f(end:-1:((m+1)/2))) / sqrt(2*m);
    rfm(((m+1)/2):end,:) = 1i*(f(2:((m-1)/2),:) - f(end:-1:((m+1)/2))) / sqrt(2*m);
end 

rfm = rfm.';
rf = zeros(size(rfm));

if mod(n,2) == 0
    rf(1,:) = rfm(1,:)/ sqrt(n);
    rf(2:(n/2),:) = (rfm(2:(n/2),:) + rfm(n:-1:(n/2+2),:)) / sqrt(2*n);
    rf((n/2+1):(end-1),:) = 1i*(rfm(2:(n/2),:) - rfm(n:-1:(n/2+2),:)) / sqrt(2*n);
    rf(end,:) = rfm(n/2+1,:)/sqrt(n);
else
    rf(1,:) = rfm(1,:)/ sqrt(n);
    rf(2:((n-1)/2),:) = (rfm(2:((n-1)/2),:) + rfm(end:-1:((n+1)/2))) / sqrt(2*n);
    rf(((n+1)/2):end,:) = 1i*(rfm(2:((n-1)/2),:) - rfm(end:-1:((n+1)/2))) / sqrt(2*n);
end 

rf = rf.';

end