%% Main script to initialize from pre-computed spectra 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.                                        
%                                                                                                                                                      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


clear all;

%% Set the main parameters
Fmax = 4000; % Maximum frequency considered in the computation of spectra

PathPrefix = pwd;
addpath('functions');
addpath(genpath('toolbox'));
addpath(genpath('data'));
addpath('temp');
TempPrefix = [PathPrefix,'/temp/'];


%% Load the pre-computed data, looking for them
% 1) in data_temp
% 2) only if not found in data temp, look in data

if ~exist('FromScratchFlag')

    if exist([TempPrefix 'SpectraRegAnt.mat'],'file')
        disp('Loading from temp');
        load([TempPrefix 'SpectraRegAnt.mat']);
    else
        disp('Loading from data');
        load('data/spectra/SpectraRegAnt.mat');
    
    end
    
    if exist([TempPrefix 'SpectraRandAnt.mat'],'file')
        disp('Loading from temp');
        load([TempPrefix 'SpectraRandAnt.mat']);
    else
        disp('Loading from data');
        load('data/spectra/SpectraRandAnt.mat');
    
    end
    
    if exist([TempPrefix 'GroundTruthODS.mat'],'file')
        disp('Loading from temp');
        load([TempPrefix 'GroundTruthODS.mat']);
    else
        disp('Loading from data');
        load('data/spectra/GroundTruthODS.mat');
    
    end
    
    if exist([TempPrefix 'SpectraRegAntD.mat'],'file')
        disp('Loading from temp');
        load([TempPrefix 'SpectraRegAntD.mat']);
    else
        disp('Loading from data');
        load('data/spectra/SpectraRegAntD.mat');
    
    end
    
    if exist([TempPrefix 'SpectraVibroD.mat'],'file')
        disp('Loading from temp');
        load([TempPrefix 'SpectraVibroD.mat']); 
    else
        disp('Loading from data');
        load('data/spectra/SpectraVibroD.mat');
    
    end

end


%% load antennas
VibroANTP = load('vibroant2000.mat');
RegANTP = load('regant1920.mat');
RegDANTP = load('regant1920.mat');
RandANTP = load('randant120.mat');
VibroDANTP = load('vibrodant1979.mat');

[SpectraVibroD,VibroDANTP] = zero_pad(SpectraVibroD,VibroDANTP);
[SpectraVibroD,VibroDANTP.XYPos] = reshape_onmeshgrid(SpectraVibroD,VibroDANTP.XYPos);
[SpectraRegAntD,RegDANTP.XYPos] = reshape_onmeshgrid(SpectraRegAntD,RegDANTP.XYPos);
[SpectraRegAnt,RegANTP.XYPos] = reshape_onmeshgrid(SpectraRegAnt,RegANTP.XYPos);

%% some shortcuts
% number of points we wish to reconstruct on the plate
Nx = length(unique(VibroANTP.XYPos(:,1)));
Ny = length(unique(VibroANTP.XYPos(:,2)));

clear FromScratchFlag;
