%% Script to reproduce Figure 8

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.                                        
%                                                                                                                                                      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% constants 

Nx = length(unique(VibroANTP.XYPos(:,1)));
Ny = length(unique(VibroANTP.XYPos(:,2)));


% Reconstruction with BPDN, from regular antenna measurements
ALGOP.Name = 'l1_constr_spgl1';
ALGOP.StoppingCriterion = 27;
ALGOP.DicoSizeX = 2*Nx;
ALGOP.DicoSizeY = 2*Ny;
ALGOP.Mask = ones(Nx,Ny);
ALGOP.StepX = 0.01;
ALGOP.StepY = 0.01;
ALGOP.DicoXLength = ALGOP.DicoSizeX*ALGOP.StepX;
ALGOP.DicoYLength = ALGOP.DicoSizeY*ALGOP.StepY;

NbMethods = 4;

ODSToPlot = cell(NbMethods,length(SPECPVibro.SelectedFreqIndices)); 

Correlations = zeros(NbMethods,length(SPECPVibro.SelectedFreqIndices));

%% Loop on modes to be imaged
for ii = 1:length(SPECPVibro.SelectedFreqIndices)
    
    % Prepare groundtruth image
    ODSFreqIdx = SPECPVibro.SelectedFreqIndices(ii);
    ODS        = SelectedGroundTruthODS(:,:,ii);
    
    Correlations(1,ii) = 1;

     % Regular 42
    DownSampleParam = [3,7,45,3,7,38];
    [Spectrum,REGRANDANTP120] = select_datasubset(SpectraRegAnt, RegANTP,ODSFreqIdx,1,'regular',DownSampleParam); 
    ODS2 = apply_sparse_reconstruction(Spectrum,SPECPRandAnt,ODSFreqIdx,REGRANDANTP120, ALGOP,VibroANTP);
    Correlations(2,ii) = compute_correlation_2d(ODS,ODS2);
    
    % Rand from reg 42
    DownSampleParam = 42;
    [Spectrum,REGRANDANTP120] = select_datasubset(SpectraRegAnt, RegANTP,ODSFreqIdx,1,'random',DownSampleParam); 
    ODS3 = apply_sparse_reconstruction(Spectrum,SPECPRandAnt,ODSFreqIdx,REGRANDANTP120, ALGOP,VibroANTP);
    Correlations(3,ii) = compute_correlation_2d(ODS,ODS3);
    
     % Rand 42
    DownSampleParam = 42;
    [Spectrum,REGRANDANTP120] = select_datasubset(SpectraRandAnt, RandANTP,ODSFreqIdx,1,'random',DownSampleParam); 
    ODS4 = apply_sparse_reconstruction(Spectrum,SPECPRandAnt,ODSFreqIdx,REGRANDANTP120, ALGOP,VibroANTP);
    Correlations(4,ii) = compute_correlation_2d(ODS,ODS4);
    
             
    % store for display
    ODSToPlot{1,ii} = flipud(Cpx2Surf(ODS));
    ODSToPlot{2,ii} = flipud(ODS2);
    ODSToPlot{3,ii} = flipud(ODS3);
    ODSToPlot{4,ii} = flipud(ODS4);
end

% create figure 8
f8=figure(8);

set(f8,'OuterPosition',[500, 500, 600, 800]);
plot_ODS(ODSToPlot,Correlations,ALGOP.Mask);

subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,1);
title('(a) Groundtruth');
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,2);
title('(b) L1REG42');
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,3);
title('(c) L1RANfREG42');
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,4);
title('(d) L1RAN42');

subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,1);
ylabel([num2str(round(SPECPVibro.FreqValues(SPECPVibro.SelectedFreqIndices(1)))),' Hz']);
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,5);
ylabel([num2str(round(SPECPVibro.FreqValues(SPECPVibro.SelectedFreqIndices(2)))),' Hz']);
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,9);
ylabel([num2str(round(SPECPVibro.FreqValues(SPECPVibro.SelectedFreqIndices(3)))),' Hz']);
subplot(length(SPECPVibro.SelectedFreqIndices),NbMethods,13);
ylabel([num2str(round(SPECPVibro.FreqValues(SPECPVibro.SelectedFreqIndices(4)))),' Hz']);


