%% Script to reproduce Figure 9

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                        
% Nearfield ACoustic HOlography with Sparse regularization (NACHOS)
% Version 1.0                                    
%     
% Copyright 2012 Antoine Peillot, Franois Ollivier, Gilles Chardon, 
%                Laurent Daudet, Nancy Bertin, Rmi Gribonval
% 
% For all details please refer to README.TXT
%
% This software is a free software distributed under the terms of the GNU 
% Public License version 3 (http://www.gnu.org/licenses/gpl.txt). You can 
% redistribute it and/or modify it under the terms of this licence.                                       
%                                                                                                                                                      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

install_ack = input('\n\n This operation will last several hours. Are you sure you want to continue ([y]/n)? ','s');

if strcmp(install_ack,'"n"'),
  install_ack = 'n';
end

if install_ack == 'n',
  return;
else
  fprintf('\n\n Now beginning...');

end

NbFreqs = length(SPECPVibro.RelevantFreqIndices);

DicoSizeX = (50:10:300);
DicoSizeY = (40:8:240);
NbDico = length(DicoSizeX);
NbSparsity = 9;

CorrelationsL1 = zeros(NbFreqs,NbDico);
CorrelationsOMP = zeros(NbFreqs,NbDico,NbSparsity);

h = waitbar(0,'Work in progress...');

ALGOP.StepX = 0.01;
ALGOP.StepY = 0.01;

Nx = length(unique(VibroANTP.XYPos(:,1)));
Ny = length(unique(VibroANTP.XYPos(:,2)));

ALGOP.Mask = ones(Nx,Ny);

%% Main loop (loop on modes)

for ii = 1:NbFreqs
    
    waitbar(ii/NbFreqs,h);
   
    % Prepare groundtruth image

    ODSFreqIdx = SPECPVibro.RelevantFreqIndices(ii);
    ODS        = RelevantGroundTruthODS(:,:,ii);
    
    nfft = 128; % the fft2d is 128x128 
    DownSampleParam = 77;
    [Spectrum, RANDANTP80] = select_datasubset(SpectraRandAnt, RandANTP, ODSFreqIdx,1,'none',DownSampleParam);
    
    % loop on dictionary size
    for jj = 1:NbDico
    
    ALGOP.DicoSizeX = DicoSizeX(jj);
    ALGOP.DicoSizeY = DicoSizeY(jj);
    ALGOP.DicoXLength = ALGOP.DicoSizeX*ALGOP.StepX;
    ALGOP.DicoYLength = ALGOP.DicoSizeY*ALGOP.StepY;
    

     % Reconstruction with BPDN
     ALGOP.Name = 'l1_constr_spgl1';
     ALGOP.StoppingCriterion = 27;
     
     ODS_RegAnt_BPDN = apply_sparse_reconstruction(Spectrum,SPECPRandAnt,ODSFreqIdx,RANDANTP80, ALGOP,VibroANTP);
     CorrelationsL1(ii,jj) = 100*compute_correlation_2d(ODS,ODS_RegAnt_BPDN);
    
     % Reconstruction with OMP
     
    for stopcrit = 2:1:10
       ALGOP.StoppingCriterion = stopcrit;
       ALGOP.Name = 'omp';
    
       ODS_RandAnt120_OMP = apply_sparse_reconstruction(Spectrum,SPECPRandAnt,ODSFreqIdx,RANDANTP80, ALGOP,VibroANTP);
       CorrelationsOMP(ii,jj,stopcrit-1) = 100*compute_correlation_2d(ODS,ODS_RandAnt120_OMP);
    end
     
    end   

end


% display

figure(9);

Abscisses1 = DicoSizeX / Nx * 100;
Abscisses2 = SPECPRegAnt.FreqValues(SPECPVibro.RelevantFreqIndices);

subplot(311); 

% please note that this figure is an example, for one mode (28) and one
% arbitrary value of the OMP stopping criterion (8) - you can change those
% values to visualize another example

CorrOMPFreq = squeeze(CorrelationsOMP(28,:,8));
CorrL1Freq = CorrelationsL1(28,:);
plot(Abscisses1,CorrL1Freq,'k',Abscisses1,CorrOMPFreq,'k:','linewidth',2);
grid on;
ylim([20,100]);
xlabel('Dictionary size (% of the plate size)');
ylabel('C [%]');
legend('L1','OMP','location','southeast');


CorrelationsOMPm=max(CorrelationsOMP,[],3);

M1=mean(CorrelationsOMPm,2);
M2=min(CorrelationsOMPm,[],2);
M3=max(CorrelationsOMPm,[],2);

P1=mean(CorrelationsL1,2);
P2=min(CorrelationsL1,[],2);
P3=max(CorrelationsL1,[],2);

subplot(312);

errorbar(Abscisses2,P1,P1-P2,P3-P1,'k','linewidth',2);
grid on;
xlabel('Frequency (Hz)');
ylabel('C [%]');
ylim([20,100]);
legend('L1','location','southeast');

subplot(313);
errorbar(Abscisses2,M1,M1-M2,M3-M1,'k:','linewidth',2);
grid on;
xlabel('Frequency (Hz)');
ylabel('C [%]');
ylim([20,100]);
legend('OMP','location','southeast');

